package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.DataGovernanceServicesMapper;
import com.zyc.system.domain.DataGovernanceServices;
import com.zyc.system.service.IDataGovernanceServicesService;

/**
 * 数据治理平台服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class DataGovernanceServicesServiceImpl implements IDataGovernanceServicesService 
{
    @Autowired
    private DataGovernanceServicesMapper dataGovernanceServicesMapper;

    /**
     * 查询数据治理平台服务
     * 
     * @param id 数据治理平台服务主键
     * @return 数据治理平台服务
     */
    @Override
    public DataGovernanceServices selectDataGovernanceServicesById(Integer id)
    {
        return dataGovernanceServicesMapper.selectDataGovernanceServicesById(id);
    }

    /**
     * 查询数据治理平台服务列表
     * 
     * @param dataGovernanceServices 数据治理平台服务
     * @return 数据治理平台服务
     */
    @Override
    public List<DataGovernanceServices> selectDataGovernanceServicesList(DataGovernanceServices dataGovernanceServices)
    {
        return dataGovernanceServicesMapper.selectDataGovernanceServicesList(dataGovernanceServices);
    }

    /**
     * 新增数据治理平台服务
     * 
     * @param dataGovernanceServices 数据治理平台服务
     * @return 结果
     */
    @Override
    public int insertDataGovernanceServices(DataGovernanceServices dataGovernanceServices)
    {
        return dataGovernanceServicesMapper.insertDataGovernanceServices(dataGovernanceServices);
    }

    /**
     * 修改数据治理平台服务
     * 
     * @param dataGovernanceServices 数据治理平台服务
     * @return 结果
     */
    @Override
    public int updateDataGovernanceServices(DataGovernanceServices dataGovernanceServices)
    {
        return dataGovernanceServicesMapper.updateDataGovernanceServices(dataGovernanceServices);
    }

    /**
     * 批量删除数据治理平台服务
     * 
     * @param ids 需要删除的数据治理平台服务主键
     * @return 结果
     */
    @Override
    public int deleteDataGovernanceServicesByIds(Integer[] ids)
    {
        return dataGovernanceServicesMapper.deleteDataGovernanceServicesByIds(ids);
    }

    /**
     * 删除数据治理平台服务信息
     * 
     * @param id 数据治理平台服务主键
     * @return 结果
     */
    @Override
    public int deleteDataGovernanceServicesById(Integer id)
    {
        return dataGovernanceServicesMapper.deleteDataGovernanceServicesById(id);
    }
}
