package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.DataGovernanceServices;
import com.zyc.system.service.IDataGovernanceServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 数据治理平台服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/DataGovernanceServicesController")
public class DataGovernanceServicesController extends BaseController
{
    @Autowired
    private IDataGovernanceServicesService dataGovernanceServicesService;

    /**
     * 查询数据治理平台服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataGovernanceServices dataGovernanceServices)
    {
        startPage();
        List<DataGovernanceServices> list = dataGovernanceServicesService.selectDataGovernanceServicesList(dataGovernanceServices);
        return getDataTable(list);
    }

    /**
     * 导出数据治理平台服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "数据治理平台服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataGovernanceServices dataGovernanceServices)
    {
        List<DataGovernanceServices> list = dataGovernanceServicesService.selectDataGovernanceServicesList(dataGovernanceServices);
        ExcelUtil<DataGovernanceServices> util = new ExcelUtil<DataGovernanceServices>(DataGovernanceServices.class);
        util.exportExcel(response, list, "数据治理平台服务数据");
    }

    /**
     * 获取数据治理平台服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataGovernanceServicesService.selectDataGovernanceServicesById(id));
    }

    /**
     * 新增数据治理平台服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "数据治理平台服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataGovernanceServices dataGovernanceServices)
    {
        return toAjax(dataGovernanceServicesService.insertDataGovernanceServices(dataGovernanceServices));
    }

    /**
     * 修改数据治理平台服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "数据治理平台服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataGovernanceServices dataGovernanceServices)
    {
        return toAjax(dataGovernanceServicesService.updateDataGovernanceServices(dataGovernanceServices));
    }

    /**
     * 删除数据治理平台服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "数据治理平台服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataGovernanceServicesService.deleteDataGovernanceServicesByIds(ids));
    }
}
